summaryrefslogtreecommitdiffstats
path: root/keduca/keducabuilder/ktagcombobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'keduca/keducabuilder/ktagcombobox.h')
-rw-r--r--keduca/keducabuilder/ktagcombobox.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/keduca/keducabuilder/ktagcombobox.h b/keduca/keducabuilder/ktagcombobox.h
index 099c6561..1644d6a7 100644
--- a/keduca/keducabuilder/ktagcombobox.h
+++ b/keduca/keducabuilder/ktagcombobox.h
@@ -25,14 +25,14 @@
#ifndef __KTAGCOMBOBOX_H__
#define __KTAGCOMBOBOX_H__
-#include <qcombobox.h>
-#include <qiconset.h>
+#include <tqcombobox.h>
+#include <tqiconset.h>
class QPopupMenu;
class QStringList;
/*
* This class should be just like qcombobox, but it should be possible
* to have have a QIconSet for each entry, and each entry should have a tag.
*
* It has also support for sub menues.
*/
@@ -41,14 +41,14 @@ class KTagComboBox : public QComboBox
Q_OBJECT
public:
- KTagComboBox(QWidget *parent=0, const char *name=0);
+ KTagComboBox(TQWidget *parent=0, const char *name=0);
~KTagComboBox();
- void insertItem(const QIconSet& icon, const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1 );
- void insertItem(const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1 );
- void insertSeparator(const QString &submenu = QString::null, int index=-1 );
- void insertSubmenu(const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1);
- void changeItem( const QString &text, int index );
+ void insertItem(const TQIconSet& icon, const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1 );
+ void insertItem(const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1 );
+ void insertSeparator(const TQString &submenu = TQString::null, int index=-1 );
+ void insertSubmenu(const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1);
+ void changeItem( const TQString &text, int index );
int count() const;
void clear();
@@ -56,19 +56,19 @@ public:
/*
* Tag of the selected item
*/
- QString currentTag() const;
- QString tag ( int i ) const;
- bool containsTag (const QString &str ) const;
+ TQString currentTag() const;
+ TQString tag ( int i ) const;
+ bool containsTag (const TQString &str ) const;
/*
* Set the current item
*/
int currentItem() const;
void setCurrentItem(int i);
- void setCurrentItem(const QString &code);
+ void setCurrentItem(const TQString &code);
// widget stuff
- virtual void setFont( const QFont & );
+ virtual void setFont( const TQFont & );
signals:
void activated( int index );
@@ -79,15 +79,15 @@ private slots:
void internalHighlight( int );
protected:
- void paintEvent( QPaintEvent * );
- void mousePressEvent( QMouseEvent * );
- void keyPressEvent( QKeyEvent *e );
+ void paintEvent( TQPaintEvent * );
+ void mousePressEvent( TQMouseEvent * );
+ void keyPressEvent( TQKeyEvent *e );
void popupMenu();
private:
// work space for the new class
- QStringList *_tags;
- QPopupMenu *_popup;
+ TQStringList *_tags;
+ TQPopupMenu *_popup;
int _current;
};
@@ -25,14 +25,14 @@
/*
* This class should be just like qcombobox, but it should be possible
- * to have have a QIconSet for each entry, and each entry should have a tag.
+ * to have have a TQIconSet for each entry, and each entry should have a tag.
*
* It has also support for sub menues.